@@ -15,7 +15,7 @@ This file contains the configuration for the LCDd server.
 
 The format is ini-file-like. It is divided into sections that start at
 markers that look like [section]. Comments are all line-based comments,
-and are lines that start with \'
+and are lines that start with \'#\' or \';\'.
 
 The server has a \'central\' section named [server]. For the menu there is
 a section called [menu]. Further each driver has a section which
@@ -39,764 +39,764 @@ Model information extracted from template /etc/LCDd.conf
 '.'=head1 BUGS
 
 This model does not support to load several drivers. Loading several drivers is probably a marginal case. Please complain to the author if this assumption is false',
-    'read_config' => [
-      {
-        'file' => 'LCDd.conf',
-        'backend' => 'ini_file',
-        'config_dir' => '/etc'
-      }
-    ],
-    'name' => 'LCDd',
     'copyright' => [
       '2011-2013, Dominique Dumont',
       '1999-2013, William Ferrell and others'
     ],
-    'license' => 'GPL-2',
     'element' => [
       'server',
       {
-        'type' => 'node',
-        'config_class_name' => 'LCDd::server'
+        'config_class_name' => 'LCDd::server',
+        'type' => 'node'
       },
       'CFontz',
       {
+        'config_class_name' => 'LCDd::CFontz',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'CFontz\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::CFontz'
+        'type' => 'warped_node'
       },
       'CFontzPacket',
       {
+        'config_class_name' => 'LCDd::CFontzPacket',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'CFontzPacket\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::CFontzPacket'
+        'type' => 'warped_node'
       },
       'CwLnx',
       {
+        'config_class_name' => 'LCDd::CwLnx',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'CwLnx\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::CwLnx'
+        'type' => 'warped_node'
       },
       'EyeboxOne',
       {
+        'config_class_name' => 'LCDd::EyeboxOne',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'EyeboxOne\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::EyeboxOne'
+        'type' => 'warped_node'
       },
       'IOWarrior',
       {
+        'config_class_name' => 'LCDd::IOWarrior',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'IOWarrior\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::IOWarrior'
+        'type' => 'warped_node'
       },
       'IrMan',
       {
+        'config_class_name' => 'LCDd::IrMan',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'IrMan\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::IrMan'
+        'type' => 'warped_node'
       },
       'MD8800',
       {
+        'config_class_name' => 'LCDd::MD8800',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'MD8800\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::MD8800'
+        'type' => 'warped_node'
       },
       'MtxOrb',
       {
+        'config_class_name' => 'LCDd::MtxOrb',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'MtxOrb\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::MtxOrb'
+        'type' => 'warped_node'
       },
       'NoritakeVFD',
       {
+        'config_class_name' => 'LCDd::NoritakeVFD',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'NoritakeVFD\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::NoritakeVFD'
+        'type' => 'warped_node'
       },
       'SureElec',
       {
+        'config_class_name' => 'LCDd::SureElec',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'SureElec\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::SureElec'
+        'type' => 'warped_node'
       },
       'bayrad',
       {
+        'config_class_name' => 'LCDd::bayrad',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'bayrad\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::bayrad'
+        'type' => 'warped_node'
       },
       'curses',
       {
+        'config_class_name' => 'LCDd::curses',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'curses\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::curses'
+        'type' => 'warped_node'
       },
       'ea65',
       {
+        'config_class_name' => 'LCDd::ea65',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'ea65\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::ea65'
+        'type' => 'warped_node'
       },
       'g15',
       {
+        'config_class_name' => 'LCDd::g15',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'g15\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::g15'
+        'type' => 'warped_node'
       },
       'glcd',
       {
+        'config_class_name' => 'LCDd::glcd',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'glcd\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::glcd'
+        'type' => 'warped_node'
       },
       'glcdlib',
       {
+        'config_class_name' => 'LCDd::glcdlib',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'glcdlib\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::glcdlib'
+        'type' => 'warped_node'
       },
       'glk',
       {
+        'config_class_name' => 'LCDd::glk',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'glk\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::glk'
+        'type' => 'warped_node'
       },
       'hd44780',
       {
+        'config_class_name' => 'LCDd::hd44780',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'hd44780\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::hd44780'
+        'type' => 'warped_node'
       },
       'icp_a106',
       {
+        'config_class_name' => 'LCDd::icp_a106',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'icp_a106\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::icp_a106'
+        'type' => 'warped_node'
       },
       'imon',
       {
+        'config_class_name' => 'LCDd::imon',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'imon\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::imon'
+        'type' => 'warped_node'
       },
       'imonlcd',
       {
+        'config_class_name' => 'LCDd::imonlcd',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'imonlcd\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::imonlcd'
+        'type' => 'warped_node'
       },
       'irtrans',
       {
+        'config_class_name' => 'LCDd::irtrans',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'irtrans\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::irtrans'
+        'type' => 'warped_node'
       },
       'joy',
       {
+        'config_class_name' => 'LCDd::joy',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'joy\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::joy'
+        'type' => 'warped_node'
       },
       'lb216',
       {
+        'config_class_name' => 'LCDd::lb216',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'lb216\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::lb216'
+        'type' => 'warped_node'
       },
       'lcdm001',
       {
+        'config_class_name' => 'LCDd::lcdm001',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'lcdm001\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::lcdm001'
+        'type' => 'warped_node'
       },
       'lcterm',
       {
+        'config_class_name' => 'LCDd::lcterm',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'lcterm\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::lcterm'
+        'type' => 'warped_node'
       },
       'lirc',
       {
+        'config_class_name' => 'LCDd::lirc',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'lirc\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::lirc'
+        'type' => 'warped_node'
       },
       'lis',
       {
+        'config_class_name' => 'LCDd::lis',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'lis\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::lis'
+        'type' => 'warped_node'
       },
       'mdm166a',
       {
+        'config_class_name' => 'LCDd::mdm166a',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'mdm166a\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::mdm166a'
+        'type' => 'warped_node'
       },
       'menu',
       {
-        'type' => 'node',
-        'config_class_name' => 'LCDd::menu'
+        'config_class_name' => 'LCDd::menu',
+        'type' => 'node'
       },
       'ms6931',
       {
+        'config_class_name' => 'LCDd::ms6931',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'ms6931\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::ms6931'
+        'type' => 'warped_node'
       },
       'mtc_s16209x',
       {
+        'config_class_name' => 'LCDd::mtc_s16209x',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'mtc_s16209x\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::mtc_s16209x'
+        'type' => 'warped_node'
       },
       'mx5000',
       {
+        'config_class_name' => 'LCDd::mx5000',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'mx5000\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::mx5000'
+        'type' => 'warped_node'
       },
       'picolcd',
       {
+        'config_class_name' => 'LCDd::picolcd',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'picolcd\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::picolcd'
+        'type' => 'warped_node'
       },
       'pyramid',
       {
+        'config_class_name' => 'LCDd::pyramid',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'pyramid\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::pyramid'
+        'type' => 'warped_node'
       },
       'sdeclcd',
       {
+        'config_class_name' => 'LCDd::sdeclcd',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'sdeclcd\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::sdeclcd'
+        'type' => 'warped_node'
       },
       'sed1330',
       {
+        'config_class_name' => 'LCDd::sed1330',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'sed1330\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::sed1330'
+        'type' => 'warped_node'
       },
       'sed1520',
       {
+        'config_class_name' => 'LCDd::sed1520',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'sed1520\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::sed1520'
+        'type' => 'warped_node'
       },
       'serialPOS',
       {
+        'config_class_name' => 'LCDd::serialPOS',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'serialPOS\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::serialPOS'
+        'type' => 'warped_node'
       },
       'serialVFD',
       {
+        'config_class_name' => 'LCDd::serialVFD',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'serialVFD\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::serialVFD'
+        'type' => 'warped_node'
       },
       'shuttleVFD',
       {
+        'config_class_name' => 'LCDd::shuttleVFD',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'shuttleVFD\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::shuttleVFD'
+        'type' => 'warped_node'
       },
       'sli',
       {
+        'config_class_name' => 'LCDd::sli',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'sli\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::sli'
+        'type' => 'warped_node'
       },
       'stv5730',
       {
+        'config_class_name' => 'LCDd::stv5730',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'stv5730\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::stv5730'
+        'type' => 'warped_node'
       },
       'svga',
       {
+        'config_class_name' => 'LCDd::svga',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'svga\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::svga'
+        'type' => 'warped_node'
       },
       't6963',
       {
+        'config_class_name' => 'LCDd::t6963',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'t6963\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::t6963'
+        'type' => 'warped_node'
       },
       'text',
       {
+        'config_class_name' => 'LCDd::text',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'text\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::text'
+        'type' => 'warped_node'
       },
       'tyan',
       {
+        'config_class_name' => 'LCDd::tyan',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'tyan\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::tyan'
+        'type' => 'warped_node'
       },
       'ula200',
       {
+        'config_class_name' => 'LCDd::ula200',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'ula200\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::ula200'
+        'type' => 'warped_node'
       },
       'vlsys_m428',
       {
+        'config_class_name' => 'LCDd::vlsys_m428',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'vlsys_m428\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::vlsys_m428'
+        'type' => 'warped_node'
       },
       'xosd',
       {
+        'config_class_name' => 'LCDd::xosd',
         'follow' => {
           'selected' => '- server Driver'
         },
         'level' => 'hidden',
-        'type' => 'warped_node',
         'rules' => [
           '$selected eq \'xosd\'',
           {
             'level' => 'normal'
           }
         ],
-        'config_class_name' => 'LCDd::xosd'
+        'type' => 'warped_node'
+      }
+    ],
+    'license' => 'GPL-2',
+    'name' => 'LCDd',
+    'read_config' => [
+      {
+        'backend' => 'ini_file',
+        'config_dir' => '/etc',
+        'file' => 'LCDd.conf'
       }
     ]
   }
